==> haskell-tasty-hedgehog-0.2.0.0-60-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hedgehog
version: 0.2.0.0
id: tasty-hedgehog-0.2.0.0-IJDrfmFjZKmAwPoVZgxmQO
key: tasty-hedgehog-0.2.0.0-IJDrfmFjZKmAwPoVZgxmQO
license: BSD-3-Clause
copyright: Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.
maintainer: dave.laing.80@gmail.com
author: Dave Laing
homepage: https://github.com/qfpl/tasty-hedghog
synopsis: Integration for tasty and hedgehog.
description:
    Integrates the hedgehog testing library with the tasty testing framework.
category: Testing
abi: fac8cbdc9214cdda1de570bb05889111
exposed: True
exposed-modules:
    Test.Tasty.Hedgehog
import-dirs: /usr/lib/ghc-8.6.3/site-local/tasty-hedgehog-0.2.0.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/tasty-hedgehog-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/tasty-hedgehog-0.2.0.0
hs-libraries: HStasty-hedgehog-0.2.0.0-IJDrfmFjZKmAwPoVZgxmQO
depends:
    base-4.12.0.0 hedgehog-0.6.1-8Rbi68UzQoa49YzIvfdzzb
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB
    tasty-1.1.0.4-KA2OQv2hxns8llKnTblJO9
haddock-interfaces: /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock
haddock-html: /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hedgehog-0.2.0.0-62-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hedgehog
version: 0.2.0.0
id: tasty-hedgehog-0.2.0.0-E2qg2icDepe4lpjqiQlBWt
key: tasty-hedgehog-0.2.0.0-E2qg2icDepe4lpjqiQlBWt
license: BSD-3-Clause
copyright: Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.
maintainer: dave.laing.80@gmail.com
author: Dave Laing
homepage: https://github.com/qfpl/tasty-hedghog
synopsis: Integration for tasty and hedgehog.
description:
    Integrates the hedgehog testing library with the tasty testing framework.
category: Testing
abi: bd28c3f00d86f15214d7733ba31a28a2
exposed: True
exposed-modules:
    Test.Tasty.Hedgehog
import-dirs: /usr/lib/ghc-8.6.3/site-local/tasty-hedgehog-0.2.0.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/tasty-hedgehog-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/tasty-hedgehog-0.2.0.0
hs-libraries: HStasty-hedgehog-0.2.0.0-E2qg2icDepe4lpjqiQlBWt
depends:
    base-4.12.0.0 hedgehog-0.6.1-GzIKSkgoX5rFpq8yRvjA2W
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB
    tasty-1.1.0.4-KA2OQv2hxns8llKnTblJO9
haddock-interfaces: /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock
haddock-html: /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
